@@ -22,9 +22,9 @@ Advanced usage:
     client = LLMClient(provider="anthropic", model="claude-3-opus-20240229")
 """
 
-__version__ = "2.1.4"
+__version__ = "3.2.1"
 __author__ = "Sreenath Menon"
-__description__ = "Universal LLM SDK | OpenAI GPT-4, Claude, Gemini, IBM WatsonX API Wrapper with Cost Optimization"
+__description__ = "Universal AI Platform: CLI + Python SDK | Multi-Provider LLM Interface for Any Use Case"
 
 from .client import LLMClient
 from .async_client import AsyncLLMClient
